==> downloads.html?file=gigkalender_v1.2.63_076.zip: gigkalender/calendar/backend_month-html.php <==
<?php
  $String = '<table class="Monatsansicht" summary="Monatsuebersicht">
              <tr>
                <td class="Monatsname" colspan="7">'.MonatsNameVonDatum ($monat).'</td>
              </tr>
              <tr>
                <th class="Wochentagsname">'.$L_Mo.'</th>
                <th class="Wochentagsname">'.$L_Tu.'</th>
                <th class="Wochentagsname">'.$L_We.'</th>
                <th class="Wochentagsname">'.$L_Th.'</th>
                <th class="Wochentagsname">'.$L_Fr.'</th>
                <th class="Wochentagsname">'.$L_Sa.'</th>
                <th class="Wochentagsname">'.$L_Su.'</th>
              </tr>
            <tr>';
  ob_start();
  $ErsterWochentag = WochentagVonDatum (1, $monat, $Jahr);
  $TimestampVonHeute = TimestampAusDatum(date("d"), date("m"), date("y"));
  $Tag = 1;
  $Zelle = 1;
  $AnzahlTagedesMonats = AnzahlTagedesMonats ($monat, $Jahr);
  if ( IsUserAdmin() ) { $UserIsAdmin = true;}
  else { $UserIsAdmin = false;}
  if ( IsUserUser() ) { $UserIsUser = true;}
  else { $UserIsUser = false;}

  for ($z=1; $z<=6; $z++)
  {
    for ($s=1; $s<=7; $s++)
    {
      if (($Zelle < $ErsterWochentag) OR ($Tag > $AnzahlTagedesMonats)) {$String .= "<td>\n</td>";}
      else
      {
        $Timestamp = TimestampAusDatum($Tag, $monat, $Jahr);
        $GigStatusDesTages = CheckGigStatusDesTages($Timestamp);
        $ToolTip = GetTooltip($Timestamp);
        $GigID = getGigVarFromGigDate ($Timestamp, 'GigID');
        if ( AnzahlGigsMitGleichemDatum( $Timestamp )>1 ) $GigStatusDesTages = 'DoubleDates';
        $String .= '<td';
        $String .= ' class="'.$GigStatusDesTages.'"';
        if ( $GigStatusDesTages!="DoubleDates" )
        {
          $String .= ' title="'.$ToolTip.'"';
        }
        $String .= '>';
        if ($Timestamp == $TimestampVonHeute) $String .= '<div class="Today">';
        $String .= '<span class="'.WochentagsNameVonDatum ($Tag, $monat, $Jahr).'">';

        // Wochentags-Zahl mit Link
        if ( $UserIsUser AND $GigStatusDesTages == "Normal")
        {
          $String .= $Tag;
        }
        else
        {
          $String .= '<a href="index.php?submenue=calendar&amp;inhalt=';
          if ( $GigStatusDesTages=="DoubleDates" ) { $String .= 'backend_selectGig&amp;timestamp='.$Timestamp.'"'; }
          else
          {
           if ( $UserIsUser ) { $String .= 'backend_showGig'; }
           else
           {
             if ( $GigStatusDesTages == "Normal" ) { $String .= 'backend_addGig&amp;job=add&amp;timestamp='.$Timestamp.''; }
             else $String .= 'backend_addGig&amp;job=edit';
           }
           $String .= '&amp;id='.$GigID.'" title="'.$ToolTip.'"';
          }
          $String .= '>'.$Tag.'</a>';
        }

        $String .= "</span>";
        if ($Timestamp == $TimestampVonHeute) {$String .= "</div>"; }
        $String .= "</td>\n";
        $Tag++;
      }
      if ($s == "7")
      {
        if ($z < "6")
        {
          $String .= "</tr><tr>";
 }
        else
        {
          $String .= "</tr>";
        }
      }
      $Zelle++;
    }
  }
  ob_end_flush();
  $String .= "</table>";

?>

==> downloads.html?file=gigkalender_v1.2.75_017.zip: gigkalender/calendar/backend_month-html.php <==
<?php
  $String = '<table class="Monatsansicht" summary="Monatsuebersicht">
              <tr>
                <td class="Monatsname" colspan="7">'.MonatsNameVonDatum ($monat).'</td>
              </tr>
              <tr>
                <th class="Wochentagsname">'.$L_Mo.'</th>
                <th class="Wochentagsname">'.$L_Tu.'</th>
                <th class="Wochentagsname">'.$L_We.'</th>
                <th class="Wochentagsname">'.$L_Th.'</th>
                <th class="Wochentagsname">'.$L_Fr.'</th>
                <th class="Wochentagsname">'.$L_Sa.'</th>
                <th class="Wochentagsname">'.$L_Su.'</th>
              </tr>
            <tr>';
  ob_start();
  $ErsterWochentag = WochentagVonDatum (1, $monat, $Jahr);
  $TimestampVonHeute = TimestampAusDatum(date("d"), date("m"), date("y"));
  $Tag = 1;
  $Zelle = 1;
  $AnzahlTagedesMonats = AnzahlTagedesMonats ($monat, $Jahr);
  

  for ($z=1; $z<=6; $z++)
  {
    for ($s=1; $s<=7; $s++)
    {
      if (($Zelle < $ErsterWochentag) OR ($Tag > $AnzahlTagedesMonats)) {$String .= "<td>\n</td>";}
      else
      {
        $Timestamp = TimestampAusDatum($Tag, $monat, $Jahr);
        $AnzahlGigsMitGleichemDatum = AnzahlGigsMitGleichemDatum($Timestamp);
        if ($AnzahlGigsMitGleichemDatum>0)
        {
          $GigStatusDesTages = CheckGigStatusDesTages($Timestamp);
          if ($AnzahlGigsMitGleichemDatum==1) $ToolTip = GetTooltip($Timestamp);
          $GigID = getGigVarFromGigDate ($Timestamp, 'GigID');
          if ($AnzahlGigsMitGleichemDatum>1) $GigStatusDesTages = 'DoubleDates';
        }
        else
        {
          $GigStatusDesTages = 'Normal';
          $ToolTip = '';
          $GigID = '';
        }
        $String .= '<td';
        $String .= ' class="'.$GigStatusDesTages.'"';
        if ( $GigStatusDesTages!="DoubleDates" )
        {
          $String .= ' title="'.$ToolTip.'"';
        }
        $String .= '>';
        if ($Timestamp == $TimestampVonHeute) $String .= '<div class="Today">';
        $String .= '<span class="'.WochentagsNameVonDatum ($Tag, $monat, $Jahr).'">';

        // Wochentags-Zahl mit Link
        if ( $UserIsUser AND $GigStatusDesTages == "Normal")
        {
          $String .= $Tag;
        }
        else
        {
          $String .= '<a href="index.php?submenue=calendar&amp;inhalt=';
          if ( $GigStatusDesTages=="DoubleDates" ) { $String .= 'backend_selectGig&amp;timestamp='.$Timestamp.'"'; }
          else
          {
           if ( $UserIsUser ) { $String .= 'backend_showGig'; }
           else
           {
             if ( $GigStatusDesTages == "Normal" ) { $String .= 'backend_addGig&amp;job=add&amp;timestamp='.$Timestamp.''; }
             else $String .= 'backend_addGig&amp;job=edit';
           }
           $String .= '&amp;id='.$GigID.'" title="'.$ToolTip.'"';
          }
          $String .= '>'.$Tag.'</a>';
        }

        $String .= "</span>";
        if ($Timestamp == $TimestampVonHeute) {$String .= "</div>"; }
        $String .= "</td>\n";
        $Tag++;
      }
      if ($s == "7")
      {
        if ($z < "6")
        {
          $String .= "</tr><tr>";
        }
        else
        {
          $String .= "</tr>";
        }
      }
      $Zelle++;
    }
  }
  ob_end_flush();
  $String .= "</table>";

?>
